# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`freeradius`](#freeradius)
* [`freeradius::config`](#freeradius--config): Manage the permissions on directories and files and then either
* [`freeradius::config::rsync`](#freeradius--config--rsync): Rsync the configurations files to `$freeradius::confdir`. It does not
* [`freeradius::install`](#freeradius--install): Install the freeradius server
* [`freeradius::service`](#freeradius--service): Configure the radiusd service
* [`freeradius::v3::conf`](#freeradius--v3--conf): @summary configure the `radiusd.conf` file   If `clients_conf_content` is set, it will add that content to the  `clients.conf` file and inclu
* [`freeradius::v3::conf::instantiate`](#freeradius--v3--conf--instantiate): Creates the 'instantiate' section of `radiusd.conf`
* [`freeradius::v3::conf::log`](#freeradius--v3--conf--log): Add a 'log' section to freeradius
* [`freeradius::v3::conf::security`](#freeradius--v3--conf--security): Add a 'security' section to freeradius.
* [`freeradius::v3::conf::thread_pool`](#freeradius--v3--conf--thread_pool): Add a 'thread pool' section to the freeradius configuration
* [`freeradius::v3::conf::users`](#freeradius--v3--conf--users): Set up the freeradius users entries
* [`freeradius::v3::modules::ldap`](#freeradius--v3--modules--ldap): Set up the LDAP module configuration.
* [`freeradius::v3::sites::ldap`](#freeradius--v3--sites--ldap): This will create a site that will authenticate using LDAP and listen

### Defined types

* [`freeradius::v3::client`](#freeradius--v3--client): Add a client to `/etc/raddb/clients.d/`
* [`freeradius::v3::conf::user`](#freeradius--v3--conf--user): Use concat to add content to the `users` file that is created by
* [`freeradius::v3::listen`](#freeradius--v3--listen): Add a 'listen' section to a freeradius configuration file.
* [`freeradius::v3::listener`](#freeradius--v3--listener): Create a global listener in the `conf.d` directory
* [`freeradius::v3::module`](#freeradius--v3--module): Copies a module definition file to the `modules-available` directory
* [`freeradius::v3::site`](#freeradius--v3--site): Copies a site definition file to the `sites-available` directory and

### Data types

* [`Freeradius::Deref`](#Freeradius--Deref): Control under which situations aliases are followed
* [`Freeradius::Listen`](#Freeradius--Listen): Types of packets to listen for
* [`Freeradius::Logdest`](#Freeradius--Logdest): Destination for log messages
* [`Freeradius::Nas`](#Freeradius--Nas): NAS-specific method to use when checking for simultaneous use
* [`Freeradius::Scope`](#Freeradius--Scope): LDAP search scope

## Classes

### <a name="freeradius"></a>`freeradius`

The freeradius class.

#### Parameters

The following parameters are available in the `freeradius` class:

* [`firewall`](#-freeradius--firewall)
* [`freeradius_name`](#-freeradius--freeradius_name)
* [`user`](#-freeradius--user)
* [`uid`](#-freeradius--uid)
* [`group`](#-freeradius--group)
* [`gid`](#-freeradius--gid)
* [`sysconfdir`](#-freeradius--sysconfdir)
* [`confdir`](#-freeradius--confdir)
* [`logdir`](#-freeradius--logdir)
* [`testcerts`](#-freeradius--testcerts)
* [`use_rsync`](#-freeradius--use_rsync)
* [`package_ensure`](#-freeradius--package_ensure)
* [`manage_sites_enabled`](#-freeradius--manage_sites_enabled)
* [`pki`](#-freeradius--pki)
* [`fips`](#-freeradius--fips)
* [`app_pki_dir`](#-freeradius--app_pki_dir)
* [`app_pki_cert`](#-freeradius--app_pki_cert)
* [`app_pki_key`](#-freeradius--app_pki_key)
* [`app_pki_ca`](#-freeradius--app_pki_ca)
* [`app_pki_ca_dir`](#-freeradius--app_pki_ca_dir)
* [`app_pki_external_source`](#-freeradius--app_pki_external_source)

##### <a name="-freeradius--firewall"></a>`firewall`

Data type: `Boolean`

If true set rules to open ports on  firewall

Default value: `simplib::lookup('simp_options::firewall', { 'default_value'    => false})`

##### <a name="-freeradius--freeradius_name"></a>`freeradius_name`

Data type: `String`

Name of the package

Default value: `'freeradius'`

##### <a name="-freeradius--user"></a>`user`

Data type: `String`



Default value: `'radiusd'`

##### <a name="-freeradius--uid"></a>`uid`

Data type: `Integer`



Default value: `95`

##### <a name="-freeradius--group"></a>`group`

Data type: `String`



Default value: `'radiusd'`

##### <a name="-freeradius--gid"></a>`gid`

Data type: `Integer`

The user and group information for the local system that is used to run
freeradius.

Default value: `95`

##### <a name="-freeradius--sysconfdir"></a>`sysconfdir`

Data type: `Stdlib::Absolutepath`

Top level configuration directory.

Default value: `'/etc'`

##### <a name="-freeradius--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The configuration directories where the radius files are kept.

Default value: `"${sysconfdir}/raddb"`

##### <a name="-freeradius--logdir"></a>`logdir`

Data type: `Stdlib::Absolutepath`

freeradius log directory

Default value: `'/var/log/freeradius'`

##### <a name="-freeradius--testcerts"></a>`testcerts`

Data type: `Boolean`

Whether or not freeradius should generate test certs at installation time.

Default value: `false`

##### <a name="-freeradius--use_rsync"></a>`use_rsync`

Data type: `Boolean`

If true rsync will be used to copy configuration files into place.
The other configuration manifests only work with freeradius version 3 or later,
if you are using an earlier version you will need to copy files this way.
rsync will not remove any files so you can use a combination of rsync and manifests.

Default value: `false`

##### <a name="-freeradius--package_ensure"></a>`package_ensure`

Data type: `String`

String to pass to the freeradius package ensure attribute

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-freeradius--manage_sites_enabled"></a>`manage_sites_enabled`

Data type: `Boolean`

If true then only sites managed by puppet will be allowed in the sites-enabled
directory.  Files that are rsync'd are not "managed" by puppet.
Use the freeradius::v3::site define or a file resource to create sites.

Default value: `false`

##### <a name="-freeradius--pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`



Default value: `simplib::lookup('simp_options::pki', { 'default_value'         => false })`

##### <a name="-freeradius--fips"></a>`fips`

Data type: `Boolean`



Default value: `simplib::lookup('simp_options::fips', {'default_value' => false })`

##### <a name="-freeradius--app_pki_dir"></a>`app_pki_dir`

Data type: `Stdlib::Absolutepath`



Default value: `'/etc/pki/simp_apps/freeradius/x509'`

##### <a name="-freeradius--app_pki_cert"></a>`app_pki_cert`

Data type: `Stdlib::Absolutepath`



Default value: `"${app_pki_dir}/public/${facts['networking']['fqdn']}.pub"`

##### <a name="-freeradius--app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::Absolutepath`



Default value: `"${app_pki_dir}/private/${facts['networking']['fqdn']}.pem"`

##### <a name="-freeradius--app_pki_ca"></a>`app_pki_ca`

Data type: `Stdlib::Absolutepath`



Default value: `"${app_pki_dir}/cacerts/cacerts.pem"`

##### <a name="-freeradius--app_pki_ca_dir"></a>`app_pki_ca_dir`

Data type: `Stdlib::Absolutepath`



Default value: `"${app_pki_dir}/cacerts"`

##### <a name="-freeradius--app_pki_external_source"></a>`app_pki_external_source`

Data type: `Stdlib::Absolutepath`



Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509' })`

### <a name="freeradius--config"></a>`freeradius::config`

rsync content or create content

### <a name="freeradius--config--rsync"></a>`freeradius::config::rsync`

remove any other files that exist in that directory

The defaults in this module use the freeradius share set up by the
`simp-simp` module in the `simp::server::rsync_shares` manifest

== Parameters

#### Parameters

The following parameters are available in the `freeradius::config::rsync` class:

* [`rsync_source`](#-freeradius--config--rsync--rsync_source)
* [`rsync_server`](#-freeradius--config--rsync--rsync_server)
* [`radius_rsync_user`](#-freeradius--config--rsync--radius_rsync_user)
* [`radius_rsync_password`](#-freeradius--config--rsync--radius_rsync_password)
* [`rsync_timeout`](#-freeradius--config--rsync--rsync_timeout)
* [`rsync_bwlimit`](#-freeradius--config--rsync--rsync_bwlimit)

##### <a name="-freeradius--config--rsync--rsync_source"></a>`rsync_source`

Data type: `String`

The  source  on the rsync server

Default value: `"freeradius_${facts['environment']}_${facts['os']['name']}/"`

##### <a name="-freeradius--config--rsync--rsync_server"></a>`rsync_server`

Data type: `Simplib::Host`

Default: 127.0.0.1
If $use_rsync_radiusd_conf is true, specify the rsync server from
which to pull here.

Default value: `simplib::lookup('simp_options::rsync::server', { 'default_value' => '127.0.0.1'})`

##### <a name="-freeradius--config--rsync--radius_rsync_user"></a>`radius_rsync_user`

Data type: `String`

Since radius holds sensitive information, the rsync space should be accordingly protected.
This has been designed with the assuption that you will utilize
the internal simplib::passgen mechanism to set the password. You can optionally specify
$radius_rsync_password

Default value: `"freeradius_systems_${facts['environment']}_${facts['os']['name'].downcase}"`

##### <a name="-freeradius--config--rsync--radius_rsync_password"></a>`radius_rsync_password`

Data type: `String`

If no password is specified, simplib::passgen will be used

Default value: `simplib::passgen($radius_rsync_user)`

##### <a name="-freeradius--config--rsync--rsync_timeout"></a>`rsync_timeout`

Data type: `Integer`

Default: '2'
If $use_rsync_radiusd_conf is true, specify the rsync connection
timeout here.

Default value: `simplib::lookup('simp_options::rsync::timeout', { 'default_value' => 2})`

##### <a name="-freeradius--config--rsync--rsync_bwlimit"></a>`rsync_bwlimit`

Data type: `Optional[Integer]`

rsync bandwidth limit

Default value: `undef`

### <a name="freeradius--install"></a>`freeradius::install`

Install the freeradius server

### <a name="freeradius--service"></a>`freeradius::service`

Configure the radiusd service

### <a name="freeradius--v3--conf"></a>`freeradius::v3::conf`

@summary configure the `radiusd.conf` file

 If `clients_conf_content` is set, it will add that content to the
 `clients.conf` file and include it in the source. Otherwise it includes
 `clients.d/*` and clients will have to be set up using the `v3/client`
 class.

 If `trigger_conf_content` is set it will add that content to `trigger.conf`
 and include this file in the radius.conf.

## Freeradius Parameters

The following parameters are settings in the radius.conf file.

  @see radiusd.conf(5) for additional information.

  @see Extract the original /etc/raddb/radiusd.conf from the freeradius rpm using
       rpm2cpio < free radius rpm> | cpio -idmv for detailed information
       on the parameters.

SIMP-Related Parameters

These parameters are effective in a larger SIMP installation

Custom Content Parameters

These parameters add custom content to various parts of the configuration.

#### Parameters

The following parameters are available in the `freeradius::v3::conf` class:

* [`cleanup_delay`](#-freeradius--v3--conf--cleanup_delay)
* [`correct_escapes`](#-freeradius--v3--conf--correct_escapes)
* [`default_acct_listener`](#-freeradius--v3--conf--default_acct_listener)
* [`hostname_lookups`](#-freeradius--v3--conf--hostname_lookups)
* [`localstatedir`](#-freeradius--v3--conf--localstatedir)
* [`max_request_time`](#-freeradius--v3--conf--max_request_time)
* [`max_requests`](#-freeradius--v3--conf--max_requests)
* [`radius_ports`](#-freeradius--v3--conf--radius_ports)
* [`trusted_nets`](#-freeradius--v3--conf--trusted_nets)
* [`protocol`](#-freeradius--v3--conf--protocol)
* [`clients_conf_content`](#-freeradius--v3--conf--clients_conf_content)
* [`proxy_conf_content`](#-freeradius--v3--conf--proxy_conf_content)
* [`trigger_conf_content`](#-freeradius--v3--conf--trigger_conf_content)
* [`users_conf_content`](#-freeradius--v3--conf--users_conf_content)

##### <a name="-freeradius--v3--conf--cleanup_delay"></a>`cleanup_delay`

Data type: `Integer[2,10]`



Default value: `5`

##### <a name="-freeradius--v3--conf--correct_escapes"></a>`correct_escapes`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--conf--default_acct_listener"></a>`default_acct_listener`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--conf--hostname_lookups"></a>`hostname_lookups`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--conf--localstatedir"></a>`localstatedir`

Data type: `Stdlib::AbsolutePath`



Default value: `'/var'`

##### <a name="-freeradius--v3--conf--max_request_time"></a>`max_request_time`

Data type: `Integer[2,120]`



Default value: `30`

##### <a name="-freeradius--v3--conf--max_requests"></a>`max_requests`

Data type: `Integer[256]`



Default value: `1024`

##### <a name="-freeradius--v3--conf--radius_ports"></a>`radius_ports`

Data type: `Array[Simplib::Port]`

The ports where freeradius will listen

Default value: `[1812, 1813]`

##### <a name="-freeradius--v3--conf--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Networks and/or hosts that are allowed to access the RADIUS server

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1', '::1']})`

##### <a name="-freeradius--v3--conf--protocol"></a>`protocol`

Data type: `Enum['udp','tcp','ALL']`

What protocols will be used to make sure the firewall is opened correctly

Default value: `'ALL'`

##### <a name="-freeradius--v3--conf--clients_conf_content"></a>`clients_conf_content`

Data type: `Optional[String]`

Content for the `clients.conf` file if not creating clients individually

Default value: `undef`

##### <a name="-freeradius--v3--conf--proxy_conf_content"></a>`proxy_conf_content`

Data type: `Optional[String]`

If `$proxy_request` is `true`, use this content for the `proxy.conf` file

Default value: `undef`

##### <a name="-freeradius--v3--conf--trigger_conf_content"></a>`trigger_conf_content`

Data type: `Optional[String]`

This content for the `trigger.conf` file

Default value: `undef`

##### <a name="-freeradius--v3--conf--users_conf_content"></a>`users_conf_content`

Data type: `Optional[String]`

The content for the `authorize` file

Default value: `undef`

### <a name="freeradius--v3--conf--instantiate"></a>`freeradius::v3::conf::instantiate`

in a file under `conf.d`.

This section is included by the directive `$INCLUDE conf.d/` in the
radiusd.conf file.

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::conf::instantiate` class:

* [`content`](#-freeradius--v3--conf--instantiate--content)

##### <a name="-freeradius--v3--conf--instantiate--content"></a>`content`

Data type: `Optional[String]`

The literal content of the section that you would like to add. Leading
and trailing spaces will be removed.

Default value: `undef`

### <a name="freeradius--v3--conf--log"></a>`freeradius::v3::conf::log`

Add a 'log' section to freeradius

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::conf::log` class:

* [`destination`](#-freeradius--v3--conf--log--destination)
* [`log_file`](#-freeradius--v3--conf--log--log_file)
* [`syslog_facility`](#-freeradius--v3--conf--log--syslog_facility)
* [`stripped_names`](#-freeradius--v3--conf--log--stripped_names)
* [`auth`](#-freeradius--v3--conf--log--auth)
* [`auth_badpass`](#-freeradius--v3--conf--log--auth_badpass)
* [`auth_goodpass`](#-freeradius--v3--conf--log--auth_goodpass)
* [`msg_goodpass`](#-freeradius--v3--conf--log--msg_goodpass)
* [`msg_badpass`](#-freeradius--v3--conf--log--msg_badpass)
* [`msg_denied`](#-freeradius--v3--conf--log--msg_denied)

##### <a name="-freeradius--v3--conf--log--destination"></a>`destination`

Data type: `Freeradius::Logdest`



Default value: `'syslog'`

##### <a name="-freeradius--v3--conf--log--log_file"></a>`log_file`

Data type: `Stdlib::AbsolutePath`



Default value: `"${freeradius::logdir}/radius.log"`

##### <a name="-freeradius--v3--conf--log--syslog_facility"></a>`syslog_facility`

Data type: `Simplib::Syslog::Facility`



Default value: `'local6'`

##### <a name="-freeradius--v3--conf--log--stripped_names"></a>`stripped_names`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--conf--log--auth"></a>`auth`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--conf--log--auth_badpass"></a>`auth_badpass`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--conf--log--auth_goodpass"></a>`auth_goodpass`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--conf--log--msg_goodpass"></a>`msg_goodpass`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--conf--log--msg_badpass"></a>`msg_badpass`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--conf--log--msg_denied"></a>`msg_denied`

Data type: `Optional[String]`



Default value: `undef`

### <a name="freeradius--v3--conf--security"></a>`freeradius::v3::conf::security`

Add a 'security' section to freeradius.

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::conf::security` class:

* [`max_attributes`](#-freeradius--v3--conf--security--max_attributes)
* [`reject_delay`](#-freeradius--v3--conf--security--reject_delay)
* [`status_server`](#-freeradius--v3--conf--security--status_server)
* [`allow_core_dumps`](#-freeradius--v3--conf--security--allow_core_dumps)
* [`chroot`](#-freeradius--v3--conf--security--chroot)
* [`chroot_path`](#-freeradius--v3--conf--security--chroot_path)
* [`chroot_user`](#-freeradius--v3--conf--security--chroot_user)
* [`chroot_group`](#-freeradius--v3--conf--security--chroot_group)

##### <a name="-freeradius--v3--conf--security--max_attributes"></a>`max_attributes`

Data type: `Integer`



Default value: `200`

##### <a name="-freeradius--v3--conf--security--reject_delay"></a>`reject_delay`

Data type: `Integer[1,5]`



Default value: `1`

##### <a name="-freeradius--v3--conf--security--status_server"></a>`status_server`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--conf--security--allow_core_dumps"></a>`allow_core_dumps`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--conf--security--chroot"></a>`chroot`

Data type: `Boolean`

whether or not to run radiusd in a chroot

Default value: `false`

##### <a name="-freeradius--v3--conf--security--chroot_path"></a>`chroot_path`

Data type: `Optional[Stdlib::Absolutepath]`

directory where the server does "chroot"

Default value: `undef`

##### <a name="-freeradius--v3--conf--security--chroot_user"></a>`chroot_user`

Data type: `Optional[String]`

User to run daemon as,must be defined if using a chroot

Default value: `undef`

##### <a name="-freeradius--v3--conf--security--chroot_group"></a>`chroot_group`

Data type: `Optional[String]`

Group to run daemon as.

Default value: `undef`

### <a name="freeradius--v3--conf--thread_pool"></a>`freeradius::v3::conf::thread_pool`

Add a 'thread pool' section to the freeradius configuration

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::conf::thread_pool` class:

* [`start_servers`](#-freeradius--v3--conf--thread_pool--start_servers)
* [`max_servers`](#-freeradius--v3--conf--thread_pool--max_servers)
* [`min_spare_servers`](#-freeradius--v3--conf--thread_pool--min_spare_servers)
* [`max_spare_servers`](#-freeradius--v3--conf--thread_pool--max_spare_servers)
* [`max_requests_per_server`](#-freeradius--v3--conf--thread_pool--max_requests_per_server)
* [`max_queue_size`](#-freeradius--v3--conf--thread_pool--max_queue_size)
* [`auto_limit_acct`](#-freeradius--v3--conf--thread_pool--auto_limit_acct)

##### <a name="-freeradius--v3--conf--thread_pool--start_servers"></a>`start_servers`

Data type: `Integer`



Default value: `5`

##### <a name="-freeradius--v3--conf--thread_pool--max_servers"></a>`max_servers`

Data type: `Integer`



Default value: `32`

##### <a name="-freeradius--v3--conf--thread_pool--min_spare_servers"></a>`min_spare_servers`

Data type: `Integer`



Default value: `3`

##### <a name="-freeradius--v3--conf--thread_pool--max_spare_servers"></a>`max_spare_servers`

Data type: `Integer`



Default value: `10`

##### <a name="-freeradius--v3--conf--thread_pool--max_requests_per_server"></a>`max_requests_per_server`

Data type: `Integer`



Default value: `0`

##### <a name="-freeradius--v3--conf--thread_pool--max_queue_size"></a>`max_queue_size`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--conf--thread_pool--auto_limit_acct"></a>`auto_limit_acct`

Data type: `Boolean`



Default value: `false`

### <a name="freeradius--v3--conf--users"></a>`freeradius::v3::conf::users`

Set up the freeradius users entries

### <a name="freeradius--v3--modules--ldap"></a>`freeradius::v3::modules::ldap`

Set up the LDAP module configuration.

#### Parameters

The following parameters are available in the `freeradius::v3::modules::ldap` class:

* [`base_dn`](#-freeradius--v3--modules--ldap--base_dn)
* [`app_pki_key`](#-freeradius--v3--modules--ldap--app_pki_key)
* [`app_pki_cert`](#-freeradius--v3--modules--ldap--app_pki_cert)
* [`app_pki_ca_dir`](#-freeradius--v3--modules--ldap--app_pki_ca_dir)
* [`confdir`](#-freeradius--v3--modules--ldap--confdir)
* [`group`](#-freeradius--v3--modules--ldap--group)
* [`base_filter`](#-freeradius--v3--modules--ldap--base_filter)
* [`client_scope`](#-freeradius--v3--modules--ldap--client_scope)
* [`client_filter`](#-freeradius--v3--modules--ldap--client_filter)
* [`client_attribute_identifier`](#-freeradius--v3--modules--ldap--client_attribute_identifier)
* [`client_attribute_secret`](#-freeradius--v3--modules--ldap--client_attribute_secret)
* [`client_attribute_shortname`](#-freeradius--v3--modules--ldap--client_attribute_shortname)
* [`client_attribute_nas_type`](#-freeradius--v3--modules--ldap--client_attribute_nas_type)
* [`client_attribute_virtual_server`](#-freeradius--v3--modules--ldap--client_attribute_virtual_server)
* [`client_attribute_require_message_authenticator`](#-freeradius--v3--modules--ldap--client_attribute_require_message_authenticator)
* [`default_profile`](#-freeradius--v3--modules--ldap--default_profile)
* [`group_scope`](#-freeradius--v3--modules--ldap--group_scope)
* [`group_filter`](#-freeradius--v3--modules--ldap--group_filter)
* [`group_name_attribute`](#-freeradius--v3--modules--ldap--group_name_attribute)
* [`group_membership_filter`](#-freeradius--v3--modules--ldap--group_membership_filter)
* [`group_membership_attribute`](#-freeradius--v3--modules--ldap--group_membership_attribute)
* [`group_cacheable_name`](#-freeradius--v3--modules--ldap--group_cacheable_name)
* [`group_cacheable_dn`](#-freeradius--v3--modules--ldap--group_cacheable_dn)
* [`identity`](#-freeradius--v3--modules--ldap--identity)
* [`ldap_connections_number`](#-freeradius--v3--modules--ldap--ldap_connections_number)
* [`ldap_debug`](#-freeradius--v3--modules--ldap--ldap_debug)
* [`ldap_timeout`](#-freeradius--v3--modules--ldap--ldap_timeout)
* [`ldap_timelimit`](#-freeradius--v3--modules--ldap--ldap_timelimit)
* [`options_chase_referrals`](#-freeradius--v3--modules--ldap--options_chase_referrals)
* [`options_dereference`](#-freeradius--v3--modules--ldap--options_dereference)
* [`options_idle`](#-freeradius--v3--modules--ldap--options_idle)
* [`options_interval`](#-freeradius--v3--modules--ldap--options_interval)
* [`options_net_timeout`](#-freeradius--v3--modules--ldap--options_net_timeout)
* [`options_probes`](#-freeradius--v3--modules--ldap--options_probes)
* [`options_rebind`](#-freeradius--v3--modules--ldap--options_rebind)
* [`password`](#-freeradius--v3--modules--ldap--password)
* [`pool_start`](#-freeradius--v3--modules--ldap--pool_start)
* [`pool_min`](#-freeradius--v3--modules--ldap--pool_min)
* [`pool_max`](#-freeradius--v3--modules--ldap--pool_max)
* [`pool_spare`](#-freeradius--v3--modules--ldap--pool_spare)
* [`pool_uses`](#-freeradius--v3--modules--ldap--pool_uses)
* [`pool_lifetime`](#-freeradius--v3--modules--ldap--pool_lifetime)
* [`pool_idle_timeout`](#-freeradius--v3--modules--ldap--pool_idle_timeout)
* [`port`](#-freeradius--v3--modules--ldap--port)
* [`profile_attribute`](#-freeradius--v3--modules--ldap--profile_attribute)
* [`random_file`](#-freeradius--v3--modules--ldap--random_file)
* [`require_cert`](#-freeradius--v3--modules--ldap--require_cert)
* [`retry_delay`](#-freeradius--v3--modules--ldap--retry_delay)
* [`start_tls`](#-freeradius--v3--modules--ldap--start_tls)
* [`user_filter`](#-freeradius--v3--modules--ldap--user_filter)
* [`user_access_attribute`](#-freeradius--v3--modules--ldap--user_access_attribute)
* [`user_access_positive`](#-freeradius--v3--modules--ldap--user_access_positive)
* [`user_scope`](#-freeradius--v3--modules--ldap--user_scope)
* [`server`](#-freeradius--v3--modules--ldap--server)
* [`post_auth_content`](#-freeradius--v3--modules--ldap--post_auth_content)
* [`accounting_content`](#-freeradius--v3--modules--ldap--accounting_content)
* [`content`](#-freeradius--v3--modules--ldap--content)

##### <a name="-freeradius--v3--modules--ldap--base_dn"></a>`base_dn`

Data type: `String`



Default value: `simplib::lookup('simp_options::ldap::base_dn')`

##### <a name="-freeradius--v3--modules--ldap--app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::AbsolutePath`

Path and name of the private SSL key file

Default value: `$freeradius::app_pki_key`

##### <a name="-freeradius--v3--modules--ldap--app_pki_cert"></a>`app_pki_cert`

Data type: `Stdlib::AbsolutePath`

Path and name of the public SSL certificate

Default value: `$freeradius::app_pki_cert`

##### <a name="-freeradius--v3--modules--ldap--app_pki_ca_dir"></a>`app_pki_ca_dir`

Data type: `Stdlib::AbsolutePath`

Path to the CA.

Default value: `$freeradius::app_pki_ca_dir`

##### <a name="-freeradius--v3--modules--ldap--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

Freeradius configuration directory

Default value: `$freeradius::confdir`

##### <a name="-freeradius--v3--modules--ldap--group"></a>`group`

Data type: `String`

Group radiusd is running under.

Default value: `$freeradius::group`

##### <a name="-freeradius--v3--modules--ldap--base_filter"></a>`base_filter`

Data type: `String`



Default value: `'(objectclass=radiusprofile)'`

##### <a name="-freeradius--v3--modules--ldap--client_scope"></a>`client_scope`

Data type: `Optional[Freeradius::Scope]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--client_filter"></a>`client_filter`

Data type: `String`



Default value: `'(objectClass=frClient)'`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_identifier"></a>`client_attribute_identifier`

Data type: `String`



Default value: `'radiusClientIdentifier'`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_secret"></a>`client_attribute_secret`

Data type: `String`



Default value: `'radiusClientSecret'`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_shortname"></a>`client_attribute_shortname`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_nas_type"></a>`client_attribute_nas_type`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_virtual_server"></a>`client_attribute_virtual_server`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--client_attribute_require_message_authenticator"></a>`client_attribute_require_message_authenticator`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--default_profile"></a>`default_profile`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--group_scope"></a>`group_scope`

Data type: `Optional[Freeradius::Scope]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--group_filter"></a>`group_filter`

Data type: `String`



Default value: `'(objectClass=posixGroup)'`

##### <a name="-freeradius--v3--modules--ldap--group_name_attribute"></a>`group_name_attribute`

Data type: `String`



Default value: `'cn'`

##### <a name="-freeradius--v3--modules--ldap--group_membership_filter"></a>`group_membership_filter`

Data type: `String`



Default value: `'(|(&(objectClass=GroupOfNames)(member=%{control:Ldap-UserDn}))(&(objectClass=GroupOfUniqueNames)(uniquemember=%{control:Ldap-UserDn})))'`

##### <a name="-freeradius--v3--modules--ldap--group_membership_attribute"></a>`group_membership_attribute`

Data type: `String`

If this does not contain a value then Group Membership Checking will not
be enabled.

Default value: `'memberOf'`

##### <a name="-freeradius--v3--modules--ldap--group_cacheable_name"></a>`group_cacheable_name`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--modules--ldap--group_cacheable_dn"></a>`group_cacheable_dn`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--modules--ldap--identity"></a>`identity`

Data type: `String`



Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value' => "cn=hostAuth,ou=Hosts,%{lookup('simp_options::ldap::base_dn')}", 'value_type' => String })`

##### <a name="-freeradius--v3--modules--ldap--ldap_connections_number"></a>`ldap_connections_number`

Data type: `Integer[1]`



Default value: `5`

##### <a name="-freeradius--v3--modules--ldap--ldap_debug"></a>`ldap_debug`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--ldap_timeout"></a>`ldap_timeout`

Data type: `Integer`



Default value: `4`

##### <a name="-freeradius--v3--modules--ldap--ldap_timelimit"></a>`ldap_timelimit`

Data type: `Integer`



Default value: `3`

##### <a name="-freeradius--v3--modules--ldap--options_chase_referrals"></a>`options_chase_referrals`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--modules--ldap--options_dereference"></a>`options_dereference`

Data type: `Freeradius::Deref`



Default value: `'never'`

##### <a name="-freeradius--v3--modules--ldap--options_idle"></a>`options_idle`

Data type: `Integer`



Default value: `60`

##### <a name="-freeradius--v3--modules--ldap--options_interval"></a>`options_interval`

Data type: `Integer`



Default value: `3`

##### <a name="-freeradius--v3--modules--ldap--options_net_timeout"></a>`options_net_timeout`

Data type: `Integer`



Default value: `1`

##### <a name="-freeradius--v3--modules--ldap--options_probes"></a>`options_probes`

Data type: `Integer`



Default value: `3`

##### <a name="-freeradius--v3--modules--ldap--options_rebind"></a>`options_rebind`

Data type: `Boolean`



Default value: `false`

##### <a name="-freeradius--v3--modules--ldap--password"></a>`password`

Data type: `String`



Default value: `simplib::lookup('simp_options::ldap::bind_pw')`

##### <a name="-freeradius--v3--modules--ldap--pool_start"></a>`pool_start`

Data type: `Integer[1]`



Default value: `5`

##### <a name="-freeradius--v3--modules--ldap--pool_min"></a>`pool_min`

Data type: `Integer[1]`



Default value: `4`

##### <a name="-freeradius--v3--modules--ldap--pool_max"></a>`pool_max`

Data type: `Integer[1]`



Default value: `10`

##### <a name="-freeradius--v3--modules--ldap--pool_spare"></a>`pool_spare`

Data type: `Integer[1]`



Default value: `3`

##### <a name="-freeradius--v3--modules--ldap--pool_uses"></a>`pool_uses`

Data type: `Integer[0]`



Default value: `0`

##### <a name="-freeradius--v3--modules--ldap--pool_lifetime"></a>`pool_lifetime`

Data type: `Integer[0]`



Default value: `0`

##### <a name="-freeradius--v3--modules--ldap--pool_idle_timeout"></a>`pool_idle_timeout`

Data type: `Integer[1]`



Default value: `60`

##### <a name="-freeradius--v3--modules--ldap--port"></a>`port`

Data type: `Simplib::Port`



Default value: `389`

##### <a name="-freeradius--v3--modules--ldap--profile_attribute"></a>`profile_attribute`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--random_file"></a>`random_file`

Data type: `Stdlib::AbsolutePath`



Default value: `'/dev/urandom'`

##### <a name="-freeradius--v3--modules--ldap--require_cert"></a>`require_cert`

Data type: `String`



Default value: `'demand'`

##### <a name="-freeradius--v3--modules--ldap--retry_delay"></a>`retry_delay`

Data type: `Integer[1]`



Default value: `30`

##### <a name="-freeradius--v3--modules--ldap--start_tls"></a>`start_tls`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--modules--ldap--user_filter"></a>`user_filter`

Data type: `String`



Default value: `'(uid=%{%{Stripped-User-Name}:-%{User-Name}})'`

##### <a name="-freeradius--v3--modules--ldap--user_access_attribute"></a>`user_access_attribute`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--user_access_positive"></a>`user_access_positive`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--modules--ldap--user_scope"></a>`user_scope`

Data type: `Optional[Freeradius::Scope]`



Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--server"></a>`server`

Data type: `Array[Simplib::Uri]`



Default value: `simplib::lookup('simp_options::ldap::uri')`

##### <a name="-freeradius--v3--modules--ldap--post_auth_content"></a>`post_auth_content`

Data type: `Optional[String]`

Override the contents of the `post-auth` section of the configuration

* Do NOT include the `post-auth` header or beginning or end curly brace

Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--accounting_content"></a>`accounting_content`

Data type: `Optional[String]`

Override the contents of the `accounting` section of the configuration

* Do NOT include the `accounting` header or beginning or end curly brace

Default value: `undef`

##### <a name="-freeradius--v3--modules--ldap--content"></a>`content`

Data type: `Optional[String]`

Specify the entire contents of the configuration file

* All other options will be ignored

Default value: `undef`

### <a name="freeradius--v3--sites--ldap"></a>`freeradius::v3::sites::ldap`

on the interface defined by `listen_ip`

The Default is to listen on all interfaces.

* **See also**
  * `/etc/raddb/sites-available/default`
    * for more information on sites

#### Parameters

The following parameters are available in the `freeradius::v3::sites::ldap` class:

* [`site_name`](#-freeradius--v3--sites--ldap--site_name)
* [`enable`](#-freeradius--v3--sites--ldap--enable)
* [`confdir`](#-freeradius--v3--sites--ldap--confdir)
* [`include_listener`](#-freeradius--v3--sites--ldap--include_listener)
* [`group`](#-freeradius--v3--sites--ldap--group)
* [`listen_ip`](#-freeradius--v3--sites--ldap--listen_ip)
* [`max_connections`](#-freeradius--v3--sites--ldap--max_connections)
* [`lifetime`](#-freeradius--v3--sites--ldap--lifetime)
* [`idle_timeout`](#-freeradius--v3--sites--ldap--idle_timeout)

##### <a name="-freeradius--v3--sites--ldap--site_name"></a>`site_name`

Data type: `String`

The name of the site

Default value: `'default'`

##### <a name="-freeradius--v3--sites--ldap--enable"></a>`enable`

Data type: `Boolean`

Whether to enable the site or not

Default value: `true`

##### <a name="-freeradius--v3--sites--ldap--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

Configuration directory for freeradius

Default value: `$freeradius::confdir`

##### <a name="-freeradius--v3--sites--ldap--include_listener"></a>`include_listener`

Data type: `Boolean`

If set to true then 'listen' sections will be set up for the site.
Otherwise the listen_ip will be ignored and the user will be required
to set up a listener using the listener.pp module.

Default value: `true`

##### <a name="-freeradius--v3--sites--ldap--group"></a>`group`

Data type: `String`

Group radiusd runs under.

Default value: `$freeradius::group`

##### <a name="-freeradius--v3--sites--ldap--listen_ip"></a>`listen_ip`

Data type: `Simplib::Host`

The ip addresses to listen on.  See setting ipaddr  in sites-enabled/default.

Default value: `'ALL'`

##### <a name="-freeradius--v3--sites--ldap--max_connections"></a>`max_connections`

Data type: `Integer`



Default value: `16`

##### <a name="-freeradius--v3--sites--ldap--lifetime"></a>`lifetime`

Data type: `Integer`



Default value: `0`

##### <a name="-freeradius--v3--sites--ldap--idle_timeout"></a>`idle_timeout`

Data type: `Integer`



Default value: `30`

## Defined types

### <a name="freeradius--v3--client"></a>`freeradius::v3::client`

Add a client to `/etc/raddb/clients.d/`

* **See also**
  * clients.conf(5)
    * for additional information.

#### Parameters

The following parameters are available in the `freeradius::v3::client` defined type:

* [`secret`](#-freeradius--v3--client--secret)
* [`ipaddr`](#-freeradius--v3--client--ipaddr)
* [`client_name`](#-freeradius--v3--client--client_name)
* [`coa_server`](#-freeradius--v3--client--coa_server)
* [`idle_timeout`](#-freeradius--v3--client--idle_timeout)
* [`lifetime`](#-freeradius--v3--client--lifetime)
* [`login`](#-freeradius--v3--client--login)
* [`max_connections`](#-freeradius--v3--client--max_connections)
* [`nas_type`](#-freeradius--v3--client--nas_type)
* [`password`](#-freeradius--v3--client--password)
* [`proto`](#-freeradius--v3--client--proto)
* [`require_message_authenticator`](#-freeradius--v3--client--require_message_authenticator)
* [`response_window`](#-freeradius--v3--client--response_window)
* [`shortname`](#-freeradius--v3--client--shortname)
* [`virtual_server`](#-freeradius--v3--client--virtual_server)

##### <a name="-freeradius--v3--client--secret"></a>`secret`

Data type: `String`

If you do not specify a secret, then one will be created for you using
`$name` as the id.

Default value: `simplib::passgen("freeradius_${name}")`

##### <a name="-freeradius--v3--client--ipaddr"></a>`ipaddr`

Data type:

```puppet
Variant[Simplib::IP,
          Simplib::IP::CIDR]
```

If set to something with a ':' in it, will be treated as ipv6addr instead.

##### <a name="-freeradius--v3--client--client_name"></a>`client_name`

Data type: `String`



Default value: `$name`

##### <a name="-freeradius--v3--client--coa_server"></a>`coa_server`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--client--idle_timeout"></a>`idle_timeout`

Data type: `Integer`



Default value: `30`

##### <a name="-freeradius--v3--client--lifetime"></a>`lifetime`

Data type: `Integer`



Default value: `0`

##### <a name="-freeradius--v3--client--login"></a>`login`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--client--max_connections"></a>`max_connections`

Data type: `Integer`



Default value: `16`

##### <a name="-freeradius--v3--client--nas_type"></a>`nas_type`

Data type: `Optional[Freeradius::Nas]`



Default value: `undef`

##### <a name="-freeradius--v3--client--password"></a>`password`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--client--proto"></a>`proto`

Data type: `Optional[Enum['udp','tcp','*']]`



Default value: `undef`

##### <a name="-freeradius--v3--client--require_message_authenticator"></a>`require_message_authenticator`

Data type: `Boolean`



Default value: `true`

##### <a name="-freeradius--v3--client--response_window"></a>`response_window`

Data type: `Optional[Float[0.0]]`



Default value: `undef`

##### <a name="-freeradius--v3--client--shortname"></a>`shortname`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--client--virtual_server"></a>`virtual_server`

Data type: `Optional[String]`



Default value: `undef`

### <a name="freeradius--v3--conf--user"></a>`freeradius::v3::conf::user`

'freeradius::v3::conf::users` module.

This module should not be used if `freeradius::v3::conf::user_conf_source` is
set in hiera. That setting will copy (what is expected to be) a complete
users file into place that you have defined.

* **See also**
  * users(5)
    * for additional details on user entries.

#### Examples

##### Adding the normal defaults for PPP

```puppet
freeradius::v3::conf::user { 'default_ppp':
  is_default => true,
  order => '500',
  content => '
   Framed-Protocol == PPP
   Framed-Protocol = PPP,
   Framed-Compression = Van-Jacobson-TCP-IP'
}
```

##### Adding a disabled user

```puppet
freeradius::v3::conf::user { 'lameuser':
 order => '0',
 content => '
  Auth-Type := Reject
  Reply-Message = "Your account has been disabled."'
}
```

#### Parameters

The following parameters are available in the `freeradius::v3::conf::user` defined type:

* [`name`](#-freeradius--v3--conf--user--name)
* [`content`](#-freeradius--v3--conf--user--content)
* [`is_default`](#-freeradius--v3--conf--user--is_default)
* [`order`](#-freeradius--v3--conf--user--order)
* [`confdir`](#-freeradius--v3--conf--user--confdir)

##### <a name="-freeradius--v3--conf--user--name"></a>`name`

The name of the user.
If `$is_default` is set to true, this will be treated as a DEFAULT user
entry and the name will be used for uniqueness.  It is recommended to use
something like 'default_ppp', 'default_slip', etc... for these entries.

##### <a name="-freeradius--v3--conf--user--content"></a>`content`

Data type: `String`

The actual content of the entry per users(5). The $name will be used as the
left hand initial value unless $is_default = true. All other portions must
be properly included, starting with the initial comparison or assignment.

* Leading whitespace is ignored.

##### <a name="-freeradius--v3--conf--user--is_default"></a>`is_default`

Data type: `Boolean`

Whether or not the entry is for a DEFAULT user entry.

Default value: `false`

##### <a name="-freeradius--v3--conf--user--order"></a>`order`

Data type: `Integer[1]`

An ordering number for including the entries in the file. This does not
*have* to be numeric, but you may end up with strange results if it is not.
The default is alphabetic.

Default value: `100`

##### <a name="-freeradius--v3--conf--user--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The configuration directory for  radiusd.

* Generally, you will want default entries at the end of the file, but this
  is not strictly enforced. You have been warned!

Default value: `simplib::lookup( 'freeradius::confdir', {'default_value' => '/etc/raddb'} )`

### <a name="freeradius--v3--listen"></a>`freeradius::v3::listen`

The following parameters are all configuration parameters.

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::listen` defined type:

* [`target`](#-freeradius--v3--listen--target)
* [`listen_type`](#-freeradius--v3--listen--listen_type)
* [`order`](#-freeradius--v3--listen--order)
* [`idle_timeout`](#-freeradius--v3--listen--idle_timeout)
* [`interface`](#-freeradius--v3--listen--interface)
* [`ipaddr`](#-freeradius--v3--listen--ipaddr)
* [`lifetime`](#-freeradius--v3--listen--lifetime)
* [`max_connections`](#-freeradius--v3--listen--max_connections)
* [`max_pps`](#-freeradius--v3--listen--max_pps)
* [`per_socket_clients`](#-freeradius--v3--listen--per_socket_clients)
* [`port`](#-freeradius--v3--listen--port)

##### <a name="-freeradius--v3--listen--target"></a>`target`

Data type: `Stdlib::Absolutepath`

The concat target to add this section to

##### <a name="-freeradius--v3--listen--listen_type"></a>`listen_type`

Data type: `Freeradius::Listen`



##### <a name="-freeradius--v3--listen--order"></a>`order`

Data type: `Integer[1]`

Indicates the order for this element amoung the concat fragments.

Default value: `100`

##### <a name="-freeradius--v3--listen--idle_timeout"></a>`idle_timeout`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--interface"></a>`interface`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--ipaddr"></a>`ipaddr`

Data type: `Simplib::Host`

Be careful not to use the same IP address on more than one listener

Default value: `'ALL'`

##### <a name="-freeradius--v3--listen--lifetime"></a>`lifetime`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--max_connections"></a>`max_connections`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--max_pps"></a>`max_pps`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--per_socket_clients"></a>`per_socket_clients`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--listen--port"></a>`port`

Data type: `Optional[Simplib::Port]`



Default value: `undef`

### <a name="freeradius--v3--listener"></a>`freeradius::v3::listener`

The following parameters are all configuration parameters.

* **See also**
  * For
    * detailed information on the parameters, extract the original
/etc/raddb/radiusd.conf from the freeradius rpm using
rpm2cpio < free radius rpm> | cpio -idmv

#### Parameters

The following parameters are available in the `freeradius::v3::listener` defined type:

* [`listen_type`](#-freeradius--v3--listener--listen_type)
* [`order`](#-freeradius--v3--listener--order)
* [`confdir`](#-freeradius--v3--listener--confdir)
* [`group`](#-freeradius--v3--listener--group)
* [`idle_timeout`](#-freeradius--v3--listener--idle_timeout)
* [`interface`](#-freeradius--v3--listener--interface)
* [`ipaddr`](#-freeradius--v3--listener--ipaddr)
* [`lifetime`](#-freeradius--v3--listener--lifetime)
* [`max_connections`](#-freeradius--v3--listener--max_connections)
* [`max_pps`](#-freeradius--v3--listener--max_pps)
* [`per_socket_clients`](#-freeradius--v3--listener--per_socket_clients)
* [`port`](#-freeradius--v3--listener--port)

##### <a name="-freeradius--v3--listener--listen_type"></a>`listen_type`

Data type: `Freeradius::Listen`



##### <a name="-freeradius--v3--listener--order"></a>`order`

Data type: `Integer[1]`

Indicates the order for this element amoung the concat fragments.

Default value: `100`

##### <a name="-freeradius--v3--listener--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`



Default value: `simplib::lookup( 'freeradius::confdir', {'default_value' => '/etc/raddb'} )`

##### <a name="-freeradius--v3--listener--group"></a>`group`

Data type: `String`



Default value: `simplib::lookup( 'freeradius::group', {'default_value' => 'radiusd'} )`

##### <a name="-freeradius--v3--listener--idle_timeout"></a>`idle_timeout`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--interface"></a>`interface`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--ipaddr"></a>`ipaddr`

Data type: `Simplib::Host`

Be careful not to use the same ip address in more than one listener

Default value: `'ALL'`

##### <a name="-freeradius--v3--listener--lifetime"></a>`lifetime`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--max_connections"></a>`max_connections`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--max_pps"></a>`max_pps`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--per_socket_clients"></a>`per_socket_clients`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-freeradius--v3--listener--port"></a>`port`

Data type: `Optional[Simplib::Port]`



Default value: `undef`

### <a name="freeradius--v3--module"></a>`freeradius::v3::module`

and if it is enabled, links it to the `mods-enabled` directory.

If neither content or source is defined and ft it enabled then it will just
create a link.

* **See also**
  * mods-available
    * for further documentation on modules.

#### Parameters

The following parameters are available in the `freeradius::v3::module` defined type:

* [`enabled`](#-freeradius--v3--module--enabled)
* [`content`](#-freeradius--v3--module--content)
* [`source`](#-freeradius--v3--module--source)
* [`confdir`](#-freeradius--v3--module--confdir)
* [`group`](#-freeradius--v3--module--group)

##### <a name="-freeradius--v3--module--enabled"></a>`enabled`

Data type: `Boolean`

If true a link will be created in mods-enabled to enable the site.

Default value: `false`

##### <a name="-freeradius--v3--module--content"></a>`content`

Data type: `Optional[String]`

The actual content of the module.  Only one of content or source can be
used.

Default value: `undef`

##### <a name="-freeradius--v3--module--source"></a>`source`

Data type: `Optional[String]`

The source file of the module definition. Only one of content or source can be
used.

Default value: `undef`

##### <a name="-freeradius--v3--module--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The configuration directory

Default value: `simplib::lookup( 'freeradius::confdir', {'default_value' => '/etc/raddb'} )`

##### <a name="-freeradius--v3--module--group"></a>`group`

Data type: `String`

The group radiusd will run under

Default value: `simplib::lookup( 'freeradius::group', {'default_value' => 'radiusd'} )`

### <a name="freeradius--v3--site"></a>`freeradius::v3::site`

if it is enabled, links it to the `sites-enabled` directory.

Note: If `freeradius::manage_sites` is enabled any site not defined in puppet
will be purged.

If neither content or source is defined and it is enabled then it will just
create a link.

* **See also**
  * site
    * definitions in sites-available for further documentation on sites.

#### Parameters

The following parameters are available in the `freeradius::v3::site` defined type:

* [`enabled`](#-freeradius--v3--site--enabled)
* [`content`](#-freeradius--v3--site--content)
* [`source`](#-freeradius--v3--site--source)
* [`confdir`](#-freeradius--v3--site--confdir)
* [`group`](#-freeradius--v3--site--group)

##### <a name="-freeradius--v3--site--enabled"></a>`enabled`

Data type: `Boolean`

If true a link will be created in sites-enabled to enable the site.

Default value: `false`

##### <a name="-freeradius--v3--site--content"></a>`content`

Data type: `Optional[String]`

The actual content of the entry per.  Only one of content or source can be
used.

Default value: `undef`

##### <a name="-freeradius--v3--site--source"></a>`source`

Data type: `Optional[String]`

The source file of the site definition. Only one of content or source can be
used.

Default value: `undef`

##### <a name="-freeradius--v3--site--confdir"></a>`confdir`

Data type: `Stdlib::Absolutepath`

The configuration directory

Default value: `simplib::lookup( 'freeradius::confdir', {'default_value' => '/etc/raddb'} )`

##### <a name="-freeradius--v3--site--group"></a>`group`

Data type: `String`

The group radiusd will run under

Default value: `simplib::lookup( 'freeradius::group', {'default_value' => 'radiusd'} )`

## Data types

### <a name="Freeradius--Deref"></a>`Freeradius::Deref`

Control under which situations aliases are followed

Alias of `Enum['never', 'searching', 'finding', 'always']`

### <a name="Freeradius--Listen"></a>`Freeradius::Listen`

Types of packets to listen for

Alias of `Enum['auth', 'acct', 'proxy', 'detail', 'status', 'coa']`

### <a name="Freeradius--Logdest"></a>`Freeradius::Logdest`

Destination for log messages

Alias of `Enum['files', 'syslog', 'stdout', 'stderr']`

### <a name="Freeradius--Nas"></a>`Freeradius::Nas`

NAS-specific method to use when checking for simultaneous use

Alias of `Enum['cisco', 'computone', 'livingston', 'max40xx', 'multitech', 'netserver', 'pathras', 'patton', 'portslave', 'tc', 'usrhiper', 'other']`

### <a name="Freeradius--Scope"></a>`Freeradius::Scope`

LDAP search scope

Alias of `Enum['base', 'one', 'sub', 'children']`

